      SUBROUTINE gr_fi_dyn(nfield,ngrid,im,jm,pfi,pdyn)
      IMPLICIT NONE
!=======================================================================
!   passage d'un champ de la grille scalaire a la grille physique
!=======================================================================
 
!-----------------------------------------------------------------------
!   declarations:
!   -------------
 
      INTEGER im,jm,ngrid,nfield
      REAL pdyn(im,jm,nfield)
      REAL pfi(ngrid,nfield)
 
      INTEGER i,j,ifield,ig
 
!-----------------------------------------------------------------------
!   calcul:
!   -------
 
      DO ifield=1,nfield
!   traitement des poles
         DO i=1,im
            pdyn(i,1,ifield)=pfi(1,ifield)
            pdyn(i,jm,ifield)=pfi(ngrid,ifield)
         ENDDO
 
!   traitement des point normaux
         DO j=2,jm-1
	    ig=2+(j-2)*(im-1)
            CALL SCOPY(im-1,pfi(ig,ifield),1,pdyn(1,j,ifield),1)
	    pdyn(im,j,ifield)=pdyn(1,j,ifield)
         ENDDO
      ENDDO
 
      RETURN
      END
 
 
!===============================================================
      subroutine advect_vert(llm,w,dt,q,plev)
!===============================================================
!   Schema amont pour l'advection verticale en 1D
!   w est la vitesse verticale dp/dt en Pa/s
!   Traitement en volumes finis 
!   d / dt ( zm q ) = delta_z ( omega q )
!   d / dt ( zm ) = delta_z ( omega )
!   avec zm = delta_z ( p )
!   si * designe la valeur au pas de temps t+dt
!   zm*(l) q*(l) - zm(l) q(l) = w(l+1) q(l+1) - w(l) q(l)
!   zm*(l) -zm(l) = w(l+1) - w(l)
!   avec w=omega * dt
!---------------------------------------------------------------
      implicit none
! arguments
      integer llm
      real w(llm+1),q(llm),plev(llm+1),dt

! local
      integer l
      real zwq(llm+1),zm(llm+1),zw(llm+1)
      real qold

!---------------------------------------------------------------

      do l=1,llm
         zw(l)=dt*w(l)
         zm(l)=plev(l)-plev(l+1)
         zwq(l)=q(l)*zw(l)
      enddo
      zwq(llm+1)=0.
      zw(llm+1)=0.
 
      do l=1,llm
         qold=q(l)
         q(l)=(q(l)*zm(l)+zwq(l+1)-zwq(l))/(zm(l)+zw(l+1)-zw(l))
         print*,'ADV Q ',zm(l),zw(l),zwq(l),qold,q(l)
      enddo

 
      return
      end

!===============================================================



      SUBROUTINE abort_gcm(modname, message, ierr)
 
      USE IOIPSL
!
! Stops the simulation cleanly, closing files and printing various
! comments
!
!  Input: modname = name of calling program
!         message = stuff to print
!         ierr    = severity of situation ( = 0 normal )
 
      character*20 modname
      integer ierr
      character*80 message
 
      write(*,*) 'in abort_gcm'
      call histclo
!     call histclo(2)
!     call histclo(3)
!     call histclo(4)
!     call histclo(5)
      write(*,*) 'out of histclo'
      write(*,*) 'Stopping in ', modname
      write(*,*) 'Reason = ',message
      if (ierr .eq. 0) then
        write(*,*) 'Everything is cool'
      else
        write(*,*) 'Houston, we have a problem ', ierr
      endif
      STOP
      END
      FUNCTION q_sat(kelvin, millibar)
!
      IMPLICIT none
!======================================================================
! Autheur(s): Z.X. Li (LMD/CNRS)
! Objet: calculer la vapeur d'eau saturante (formule Centre Euro.)
!======================================================================
! Arguments:
! kelvin---input-R: temperature en Kelvin
! millibar--input-R: pression en mb
!
! q_sat----output-R: vapeur d'eau saturante en kg/kg
!======================================================================
!
      REAL q_sat, kelvin, millibar
!
      REAL r2es
      PARAMETER (r2es=611.14 *18.0153/28.9644)
!
      REAL r3les, r3ies, r3es
      PARAMETER (R3LES=17.269)
      PARAMETER (R3IES=21.875)
!
      REAL r4les, r4ies, r4es
      PARAMETER (R4LES=35.86)
      PARAMETER (R4IES=7.66)
!
      REAL rtt
      PARAMETER (rtt=273.16)
!
      REAL retv
      PARAMETER (retv=28.9644/18.0153 - 1.0)
!
      REAL zqsat
      REAL temp, pres
!     ------------------------------------------------------------------
!
!
      temp = kelvin
      pres = millibar * 100.0
!      write(*,*)'kelvin,millibar=',kelvin,millibar
!      write(*,*)'temp,pres=',temp,pres
!
      IF (temp .LE. rtt) THEN
         r3es = r3ies
         r4es = r4ies
      ELSE
         r3es = r3les
         r4es = r4les
      ENDIF
!
      zqsat=r2es/pres * EXP ( r3es*(temp-rtt) / (temp-r4es) )
      zqsat=MIN(0.5,ZQSAT)
      zqsat=zqsat/(1.-retv  *zqsat)
!
      q_sat = zqsat
!
      RETURN
      END
      subroutine scopy(n,sx,incx,sy,incy)
!
      IMPLICIT NONE
!
      integer n,incx,incy,ix,iy,i
      real sx((n-1)*incx+1),sy((n-1)*incy+1)
!
      iy=1
      ix=1
      do 10 i=1,n
	 sy(iy)=sx(ix)
         ix=ix+incx
         iy=iy+incy
10    continue
!
      return
      end
      subroutine wrgradsfi(if,nl,field,name,titlevar)
      implicit none
 
!   Declarations
 
#include "gradsdef.h"
 
!   arguments
      integer if,nl
      real field(imx*jmx*lmx)
      character*10 name,file
      character*10 titlevar
 
!   local
 
      integer im,jm,lm,i,j,l,lnblnk,iv,iii,iji,iif,ijf
 
      logical writectl
 
 
      writectl=.false.
 
!     print*,if,iid(if),jid(if),ifd(if),jfd(if)
      iii=iid(if)
      iji=jid(if)
      iif=ifd(if)
      ijf=jfd(if)
      im=iif-iii+1
      jm=ijf-iji+1
      lm=lmd(if)


!     print*,'im,jm,lm,name,firsttime(if)'
!     print*,im,jm,lm,name,firsttime(if)
 
      if(firsttime(if)) then
         if(name.eq.var(1,if)) then
            firsttime(if)=.false.
            ivar(if)=1
         print*,'fin de l initialiation de l ecriture du fichier'
         print*,file
           print*,'fichier no: ',if
           print*,'unit ',unit(if)
           print*,'nvar  ',nvar(if)
           print*,'vars ',(var(iv,if),iv=1,nvar(if))
         else
            ivar(if)=ivar(if)+1
            nvar(if)=ivar(if)
            var(ivar(if),if)=name
            tvar(ivar(if),if)=titlevar(1:lnblnk(titlevar))
            nld(ivar(if),if)=nl
            print*,'initialisation ecriture de ',var(ivar(if),if)
            print*,'if ivar(if) nld ',if,ivar(if),nld(ivar(if),if)
         endif
         writectl=.true.
         itime(if)=1
      else
         ivar(if)=mod(ivar(if),nvar(if))+1
         if (ivar(if).eq.nvar(if)) then
            writectl=.true.
            itime(if)=itime(if)+1
         endif
 
         if(var(ivar(if),if).ne.name) then
           print*,'Il faut stoker la meme succession de champs a chaque'
           print*,'pas de temps'
           print*,'fichier no: ',if
           print*,'unit ',unit(if)
           print*,'nvar  ',nvar(if)
           print*,'vars ',(var(iv,if),iv=1,nvar(if))
 
           stop
         endif
      endif
 
!     print*,'ivar(if),nvar(if),var(ivar(if),if),writectl'
!     print*,ivar(if),nvar(if),var(ivar(if),if),writectl
      do l=1,nl
         irec(if)=irec(if)+1
!        print*,'Ecrit rec=',irec(if),iii,iif,iji,ijf,
!    s (l-1)*imd(if)*jmd(if)+(iji-1)*imd(if)+iii
!    s ,(l-1)*imd(if)*jmd(if)+(ijf-1)*imd(if)+iif
         write(unit(if)+1,rec=irec(if))
     s   ((field((l-1)*imd(if)*jmd(if)+(j-1)*imd(if)+i)
     s   ,i=iii,iif),j=iji,ijf)
      enddo
      if (writectl) then
 
      file=fichier(if)
!   WARNING! on reecrase le fichier .ctl a chaque ecriture
      open(unit(if),file=file(1:lnblnk(file))//'.ctl',
     &         form='formatted',status='unknown')
      write(unit(if),'(a5,1x,a40)')
     &       'DSET ','^'//file(1:lnblnk(file))//'.dat'
 
      write(unit(if),'(a12)') 'UNDEF 1.0E30'
      write(unit(if),'(a5,1x,a40)') 'TITLE ',title(if)
      call formcoord(unit(if),im,xd(iii,if),1.,.false.,'XDEF')
      call formcoord(unit(if),jm,yd(iji,if),1.,.true.,'YDEF')
      call formcoord(unit(if),lm,zd(1,if),1.,.false.,'ZDEF')
      write(unit(if),'(a4,i10,a30)')
     &       'TDEF ',itime(if),' LINEAR 07AUG1998 30MN '
      write(unit(if),'(a4,2x,i5)') 'VARS',nvar(if)
      do iv=1,nvar(if)
!        print*,'if,var(iv,if),nld(iv,if),nld(iv,if)-1/nld(iv,if)'
!        print*,if,var(iv,if),nld(iv,if),nld(iv,if)-1/nld(iv,if)
         write(unit(if),1000) var(iv,if),nld(iv,if)-1/nld(iv,if)
     &     ,99,tvar(iv,if)
      enddo
      write(unit(if),'(a7)') 'ENDVARS'
!
1000  format(a5,3x,i4,i3,1x,a39)
 
      close(unit(if))
 
      endif ! writectl
 
      return
 
      END
 
      subroutine inigrads(if,im
     s  ,x,fx,xmin,xmax,jm,y,ymin,ymax,fy,lm,z,fz
     s  ,dt,file,titlel)
 
 
      implicit none
 
      integer if,im,jm,lm,i,j,l,lnblnk
      real x(im),y(jm),z(lm),fx,fy,fz,dt
      real xmin,xmax,ymin,ymax
      integer nf
 
      character file*10,titlel*40
 
#include "gradsdef.h"
 
      data unit/24,32,34,36,38,40,42,44,46,48/
      data nf/0/
 
      if (if.le.nf) stop'verifier les appels a inigrads'
 
      print*,'Entree dans inigrads'
 
      nf=if
      title(if)=titlel
      ivar(if)=0
 
      fichier(if)=file(1:lnblnk(file))
 
      firsttime(if)=.true.
      dtime(if)=dt
 
      iid(if)=1
      ifd(if)=im
      imd(if)=im
      do i=1,im
         xd(i,if)=x(i)*fx
         if(xd(i,if).lt.xmin) iid(if)=i+1
         if(xd(i,if).le.xmax) ifd(if)=i
      enddo
      print*,'On stoke du point ',iid(if),'  a ',ifd(if),' en x'
 
      jid(if)=1
      jfd(if)=jm
      jmd(if)=jm
      do j=1,jm
         yd(j,if)=y(j)*fy
         if(yd(j,if).gt.ymax) jid(if)=j+1
         if(yd(j,if).ge.ymin) jfd(if)=j
      enddo
      print*,'On stoke du point ',jid(if),'  a ',jfd(if),' en y'

      print*,'Open de dat'
      print*,'file=',file
      print*,'fichier(if)=',fichier(if)
 
      print*,4*(ifd(if)-iid(if))*(jfd(if)-jid(if))
      print*,file(1:lnblnk(file))//'.dat'
 
      OPEN (unit(if)+1,FILE=file(1:lnblnk(file))//'.dat',
     s   FORM='UNFORMATTED',
     s   ACCESS='DIRECT'
     s  ,RECL=4*(ifd(if)-iid(if)+1)*(jfd(if)-jid(if)+1))
 
      print*,'Open de dat ok'
 
      lmd(if)=lm
      do l=1,lm
         zd(l,if)=z(l)*fz
      enddo
 
      irec(if)=0
!CR 
!      print*,if,imd(if),jmd(if),lmd(if)
!      print*,'if,imd(if),jmd(if),lmd(if)'
 
      return
      end
      SUBROUTINE gr_dyn_fi(nfield,im,jm,ngrid,pdyn,pfi)
      IMPLICIT NONE
!=======================================================================
!   passage d'un champ de la grille scalaire a la grille physique
!=======================================================================
 
!-----------------------------------------------------------------------
!   declarations:
!   -------------
 
      INTEGER im,jm,ngrid,nfield
      REAL pdyn(im,jm,nfield)
      REAL pfi(ngrid,nfield)
 
      INTEGER j,ifield,ig
 
!-----------------------------------------------------------------------
!   calcul:
!   -------
 
      IF(ngrid.NE.2+(jm-2)*(im-1).AND.ngrid.NE.1)
     s    STOP 'probleme de dim'
!   traitement des poles
      CALL SCOPY(nfield,pdyn,im*jm,pfi,ngrid)
      CALL SCOPY(nfield,pdyn(1,jm,1),im*jm,pfi(ngrid,1),ngrid)
 
!   traitement des point normaux
      DO ifield=1,nfield
         DO j=2,jm-1
	    ig=2+(j-2)*(im-1)
            CALL SCOPY(im-1,pdyn(1,j,ifield),1,pfi(ig,ifield),1)
         ENDDO
      ENDDO
 
      RETURN
      END
 
      subroutine writelim
     s   (phy_nat,phy_alb,phy_sst,phy_bil,phy_rug,phy_ice,
     s    phy_fter,phy_foce,phy_flic,phy_fsic)

      use dimphy
      implicit none
!
#include "dimensions.h"
#include "netcdf.inc"
 
      integer klon1d
      integer k
      parameter (klon1d=1)
      REAL phy_nat(klon1d,360)
      REAL phy_alb(klon1d,360)
      REAL phy_sst(klon1d,360)
      REAL phy_bil(klon1d,360)
      REAL phy_rug(klon1d,360)
      REAL phy_ice(klon1d,360)
      REAL phy_fter(klon1d,360)
      REAL phy_foce(klon1d,360)
      REAL phy_flic(klon1d,360)
      REAL phy_fsic(klon1d,360)
 
      INTEGER ierr
      INTEGER dimfirst(3)
      INTEGER dimlast(3)
!
      INTEGER nid, ndim, ntim
      INTEGER dims(2), debut(2), epais(2)
      INTEGER id_tim
      INTEGER id_NAT, id_SST, id_BILS, id_RUG, id_ALB
      INTEGER id_FTER,id_FOCE,id_FSIC,id_FLIC
 
      PRINT*, 'Ecriture du fichier limit'
!
      ierr = NF_CREATE ("limit.nc", NF_CLOBBER, nid)
!
      ierr = NF_PUT_ATT_TEXT (nid, NF_GLOBAL, "title", 30,
     .                       "Fichier conditions aux limites")
      ierr = NF_DEF_DIM (nid, "points_physiques", klon1d, ndim)
      ierr = NF_DEF_DIM (nid, "time", NF_UNLIMITED, ntim)
!
      dims(1) = ndim
      dims(2) = ntim
!
!cc      ierr = NF_DEF_VAR (nid, "TEMPS", NF_DOUBLE, 1,ntim, id_tim)
      ierr = NF_DEF_VAR (nid, "TEMPS", NF_FLOAT, 1,ntim, id_tim)
      ierr = NF_PUT_ATT_TEXT (nid, id_tim, "title", 17,
     .                        "Jour dans l annee")
!cc      ierr = NF_DEF_VAR (nid, "NAT", NF_DOUBLE, 2,dims, id_NAT)
      ierr = NF_DEF_VAR (nid, "NAT", NF_FLOAT, 2,dims, id_NAT)
      ierr = NF_PUT_ATT_TEXT (nid, id_NAT, "title", 23,
     .                        "Nature du sol (0,1,2,3)")
!cc      ierr = NF_DEF_VAR (nid, "SST", NF_DOUBLE, 2,dims, id_SST)
      ierr = NF_DEF_VAR (nid, "SST", NF_FLOAT, 2,dims, id_SST)
      ierr = NF_PUT_ATT_TEXT (nid, id_SST, "title", 35,
     .                        "Temperature superficielle de la mer")
!cc      ierr = NF_DEF_VAR (nid, "BILS", NF_DOUBLE, 2,dims, id_BILS)
      ierr = NF_DEF_VAR (nid, "BILS", NF_FLOAT, 2,dims, id_BILS)
      ierr = NF_PUT_ATT_TEXT (nid, id_BILS, "title", 32,
     .                        "Reference flux de chaleur au sol")
!cc      ierr = NF_DEF_VAR (nid, "ALB", NF_DOUBLE, 2,dims, id_ALB)
      ierr = NF_DEF_VAR (nid, "ALB", NF_FLOAT, 2,dims, id_ALB)
      ierr = NF_PUT_ATT_TEXT (nid, id_ALB, "title", 19,
     .                        "Albedo a la surface")
!cc      ierr = NF_DEF_VAR (nid, "RUG", NF_DOUBLE, 2,dims, id_RUG)
      ierr = NF_DEF_VAR (nid, "RUG", NF_FLOAT, 2,dims, id_RUG)
      ierr = NF_PUT_ATT_TEXT (nid, id_RUG, "title", 8,
     .                        "Rugosite")

      ierr = NF_DEF_VAR (nid, "FTER", NF_FLOAT, 2,dims, id_FTER)
      ierr = NF_PUT_ATT_TEXT (nid, id_FTER, "title", 8,"Frac. Terre")
      ierr = NF_DEF_VAR (nid, "FOCE", NF_FLOAT, 2,dims, id_FOCE)
      ierr = NF_PUT_ATT_TEXT (nid, id_FOCE, "title", 8,"Frac. Terre")
      ierr = NF_DEF_VAR (nid, "FSIC", NF_FLOAT, 2,dims, id_FSIC)
      ierr = NF_PUT_ATT_TEXT (nid, id_FSIC, "title", 8,"Frac. Terre")
      ierr = NF_DEF_VAR (nid, "FLIC", NF_FLOAT, 2,dims, id_FLIC)
      ierr = NF_PUT_ATT_TEXT (nid, id_FLIC, "title", 8,"Frac. Terre")
!
      ierr = NF_ENDDEF(nid)
!
      DO k = 1, 360
!
      debut(1) = 1
      debut(2) = k
      epais(1) = klon1d
      epais(2) = 1
!
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR1_DOUBLE (nid,id_tim,k,DBLE(k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_NAT,debut,epais,phy_nat(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_SST,debut,epais,phy_sst(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_BILS,debut,epais,phy_bil(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_ALB,debut,epais,phy_alb(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_RUG,debut,epais,phy_rug(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_FTER,debut,epais,phy_fter(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_FOCE,debut,epais,phy_foce(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_FSIC,debut,epais,phy_fsic(1,k))
      ierr = NF_PUT_VARA_DOUBLE (nid,id_FLIC,debut,epais,phy_flic(1,k))
#else
      ierr = NF_PUT_VAR1_REAL (nid,id_tim,k,FLOAT(k))
      ierr = NF_PUT_VARA_REAL (nid,id_NAT,debut,epais,phy_nat(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_SST,debut,epais,phy_sst(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_BILS,debut,epais,phy_bil(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_ALB,debut,epais,phy_alb(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_RUG,debut,epais,phy_rug(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_FTER,debut,epais,phy_fter(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_FOCE,debut,epais,phy_foce(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_FSIC,debut,epais,phy_fsic(1,k))
      ierr = NF_PUT_VARA_REAL (nid,id_FLIC,debut,epais,phy_flic(1,k))

#endif
!
      ENDDO
!
      ierr = NF_CLOSE(nid)
!
      return
      end
 
      SUBROUTINE disvert(pa,preff,ap,bp,dpres,presnivs,nivsigs,nivsig)
 
!    Auteur :  P. Le Van .
!
      IMPLICIT NONE
 
#include "dimensions.h"
#include "paramet.h"
!
!=======================================================================
!
!
!    s = sigma ** kappa   :  coordonnee  verticale
!    dsig(l)            : epaisseur de la couche l ds la coord.  s
!    sig(l)             : sigma a l'interface des couches l et l-1
!    ds(l)              : distance entre les couches l et l-1 en coord.s
!
!=======================================================================
!
      REAL pa,preff
      REAL ap(llmp1),bp(llmp1),dpres(llm),nivsigs(llm),nivsig(llmp1)
      REAL presnivs(llm)
!
!   declarations:
!   -------------
!
      REAL sig(llm+1),dsig(llm)
!
      INTEGER l
      REAL snorm
      REAL alpha,beta,gama,delta,deltaz,h
      INTEGER np,ierr
      REAL pi,x
 
!-----------------------------------------------------------------------
!
      pi=2.*ASIN(1.)
 
      OPEN(99,file='sigma.def',status='old',form='formatted',
     s   iostat=ierr)
 
!-----------------------------------------------------------------------
!   cas 1 on lit les options dans sigma.def:
!   ----------------------------------------
 
      IF (ierr.eq.0) THEN
 
      print*,'WARNING!!! on lit les options dans sigma.def'
      READ(99,*) deltaz
      READ(99,*) h
      READ(99,*) beta
      READ(99,*) gama
      READ(99,*) delta
      READ(99,*) np
      CLOSE(99)
      alpha=deltaz/(llm*h)
!
 
       DO 1  l = 1, llm
       dsig(l) = (alpha+(1.-alpha)*exp(-beta*(llm-l)))*
     $          ( (tanh(gama*l)/tanh(gama*llm))**np +
     $            (1.-l/FLOAT(llm))*delta )
   1   CONTINUE
 
       sig(1)=1.
       DO 101 l=1,llm-1
          sig(l+1)=sig(l)*(1.-dsig(l))/(1.+dsig(l))
101    CONTINUE
       sig(llm+1)=0.
 
       DO 2  l = 1, llm
       dsig(l) = sig(l)-sig(l+1)
   2   CONTINUE
!
 
      ELSE
!-----------------------------------------------------------------------
!   cas 2 ancienne discretisation (LMD5...):
!   ----------------------------------------
 
      PRINT*,'WARNING!!! Ancienne discretisation verticale'
 
      h=7.
      snorm  = 0.
      DO l = 1, llm
         x = 2.*asin(1.) * (FLOAT(l)-0.5) / float(llm+1)
         dsig(l) = 1.0 + 7.0 * SIN(x)**2
         snorm = snorm + dsig(l)
      ENDDO
      snorm = 1./snorm
      DO l = 1, llm
         dsig(l) = dsig(l)*snorm
      ENDDO
      sig(llm+1) = 0.
      DO l = llm, 1, -1
         sig(l) = sig(l+1) + dsig(l)
      ENDDO
 
      ENDIF
 
 
      DO l=1,llm
        nivsigs(l) = FLOAT(l)
      ENDDO
 
      DO l=1,llmp1
        nivsig(l)= FLOAT(l)
      ENDDO
 
!
!    ....  Calculs  de ap(l) et de bp(l)  ....
!    .........................................
!
!
!   .....  pa et preff sont lus  sur les fichiers start par lectba  .....
!
 
      bp(llmp1) =   0.
 
      DO l = 1, llm
!c
!cc    ap(l) = 0.
!cc    bp(l) = sig(l)
 
      bp(l) = EXP( 1. -1./( sig(l)*sig(l)) )
      ap(l) = pa * ( sig(l) - bp(l) )
!
      ENDDO
      ap(llmp1) = pa * ( sig(llmp1) - bp(llmp1) )
 
      PRINT *,' BP '
      PRINT *,  bp
      PRINT *,' AP '
      PRINT *,  ap
 
      DO l = 1, llm
       dpres(l) = bp(l) - bp(l+1)
       presnivs(l) = 0.5 *( ap(l)+bp(l)*preff + ap(l+1)+bp(l+1)*preff )
      ENDDO
 
      PRINT *,' PRESNIVS '
      PRINT *,presnivs
 
      RETURN
      END
!
! $Header: /home/cvsroot/LMDZ4/libf/dyn3d/iniadvtrac.F,v 1.4 2007-06-04 13:34:26 fairhead Exp $
!
!
!
      subroutine iniadvtrac(nq)
      USE ioipsl
      IMPLICIT NONE
!=======================================================================
!
!   Auteur:  P. Le Van /L. Fairhead/F.Hourdin
!   -------
!   Modif special traceur F.Forget 05/94
!   Modif M-A Filiberti 02/02 lecture de traceur.def
!
!   Objet:
!   ------
!
!   GCM LMD nouvelle grille
!
!=======================================================================
!   ... modification de l'integration de q ( 26/04/94 ) ....
!-----------------------------------------------------------------------
!   Declarations:
!   -------------
!
#include "dimensions.h"
#include "advtrac.h"

!   local
      character*3 descrq(30)
      character*1 txts(3)
      character*2 txtp(9)
      character*13 str1,str2,str3

      integer nq,iq,iiq,iiiq,ierr,ii
      integer lnblnk
      external lnblnk

      data txts/'x','y','z'/
      data txtp/'x','y','z','xx','xy','xz','yy','yz','zz'/

!-----------------------------------------------------------------------
!   Initialisations:
!   ----------------
      descrq(14)='VLH'
      descrq(10)='VL1'
      descrq(11)='VLP'
      descrq(12)='FH1'
      descrq(13)='FH2'
      descrq(16)='PPM'
      descrq(17)='PPS'
      descrq(18)='PPP'
      descrq(20)='SLP'
      descrq(30)='PRA'

#ifdef INCA

      CALL init_transport( 
     $     hadv_flg,
     $     vadv_flg,
     $     conv_flg,
     $     pbl_flg,
     $     tracnam)
#endif

!-----------------------------------------------------------------------
!        Choix  des schemas d'advection pour l'eau et les traceurs
!
!     iadv = 1    schema  transport type "humidite specifique LMD"
!     iadv = 2    schema   amont
!     iadv = 14    schema  Van-leer + humidite specifique 
!                            Modif F.Codron
!     iadv = 10   schema  Van-leer (retenu pour l'eau vapeur et liquide)
!     iadv = 11   schema  Van-Leer pour hadv et version PPM (Monotone) pour vadv
!     iadv = 12   schema  Frederic Hourdin I
!     iadv = 13   schema  Frederic Hourdin II
!     iadv = 16   schema  PPM Monotone(Collela & Woodward 1984)
!     iadv = 17   schema  PPM Semi Monotone (overshoots autoriss)
!     iadv = 18   schema  PPM Positif Defini (overshoots undershoots autoriss)
!     iadv = 20   schema  Slopes
!     iadv = 30   schema  Prather
!
!        Dans le tableau q(ij,l,iq) : iq = 1  pour l'eau vapeur
!                                     iq = 2  pour l'eau liquide
!        Et eventuellement            iq = 3,nqmx pour les autres traceurs
!
!        iadv(1): choix pour l'eau vap. et  iadv(2) : choix pour l'eau liq.
!------------------------------------------------------------------------
!     Choix du schema d'advection
!------------------------------------------------------------------
! choix par defaut = van leer pour tous les traceurs
      do iq=1,nqmx
       iadv(iq)=10
       str1(1:1)='q'
       if (nqmx.le.99) then
       WRITE(str1(2:3),'(i2.2)') iq
       else
       WRITE(str1(2:4),'(i3.3)') iq
       endif
       tnom(iq)=str1
       tname(iq)=tnom(iq) 
       str2=tnom(iq) 
       ttext(iq)=str2(1:lnblnk(str2))//descrq(iadv(iq))
      end do
      nq=nqmx
!------------------------------------------------------------------
!     Choix du schema pour l'advection
!    dans fichier traceur.def
!------------------------------------------------------------------
#ifdef INCA
! le module de chimie fournit les noms des traceurs
! et les schemas d'advection associes.
      tnom(1)='H2Ov'
      tnom(2)='H2Ol'
      nq=nbtrac+2
       if (nq.gt.nqmx) then
       print*,'nombre de traceurs incompatible INCA/LMDZT'
       stop
       endif
      do iq =3,nq
      tnom(iq)=tracnam(iq-2)
      end do
      do iq =1,nq
      hadv(iq)= hadv_flg(iq) 
      vadv(iq)= vadv_flg(iq) 
      end do
#else
      print*,'ouverture de traceur.def'
      open(90,file='traceur.def',form='formatted',status='old',
     s     iostat=ierr)
      if(ierr.eq.0) then
        print*,'ouverture de traceur.def ok'
        read(90,*) nq
        print*,'nombre de traceurs ',nq
        if (nq.gt.nqmx) then
          print*,'nombre de traceurs trop important'
          print*,'verifier traceur.def'
          stop
        endif
!
        do iq=1,nq
          read(90,999) hadv(iq),vadv(iq),tnom(iq)
        end do
        close(90)  
        PRINT*,'lecture de traceur.def :'   
        do iq=1,nq
          write(*,*) hadv(iq),vadv(iq),tnom(iq)
        end do       
      else
        print*,'pb ouverture traceur.def'
        print*,'ATTENTION on prend des valeurs par defaut'
        nq = 4
        hadv(1) = 14
        vadv(1) = 14
        tnom(1) = 'H2Ov'
        hadv(2) = 10
        vadv(2) = 10
        tnom(2) = 'H2Ol'
        hadv(3) = 10
        vadv(3) = 10
        tnom(3) = 'RN'
        hadv(4) = 10
        vadv(4) = 10
        tnom(4) = 'PB'
      ENDIF
      PRINT*,'Valeur de traceur.def :'
      do iq=1,nq
        write(*,*) hadv(iq),vadv(iq),tnom(iq)
      end do       

#endif
! a partir du nom court du traceur et du schema d'advection au detemine le nom long.
        iiq=0
        ii=0
        do iq=1,nq 
         iiq=iiq+1
         if (hadv(iq).ne.vadv(iq)) then
           if (hadv(iq).eq.10.and.vadv(iq).eq.16) then
             iadv(iiq)=11
           else
             print*,'le choix des schemas d''advection H et V'
             print*, 'est non disponible actuellement'
             stop 
           endif
         else
          iadv(iiq)=hadv(iq)
         endif
! verification nombre de traceurs
          if (iadv(iiq).lt.20) then
             ii=ii+1
          elseif (iadv(iiq).eq.20) then
             ii=ii+4
          elseif (iadv(iiq).eq.30) then
             ii=ii+10
          endif
 
         str1=tnom(iq)
         tname(iiq)=tnom(iq)
         IF (iadv(iiq).eq.0) THEN
           ttext(iiq)=str1(1:lnblnk(str1))
         ELSE
           ttext(iiq)=str1(1:lnblnk(str1))//descrq(iadv(iiq))
         endif
         str2=ttext(iiq)
!   schemas tenant compte des moments d'ordre superieur.
          if (iadv(iiq).eq.20) then
             do iiiq=1,3
               iiq=iiq+1
               iadv(iiq)=-20
               ttext(iiq)=str2(1:lnblnk(str2))//txts(iiiq)
               tname(iiq)=str1(1:lnblnk(str1))//txts(iiiq)
              enddo
            elseif (iadv(iiq).eq.30) then
              do iiiq=1,9
               iiq=iiq+1
               iadv(iiq)=-30
               ttext(iiq)=str2(1:lnblnk(str2))//txtp(iiiq)
               tname(iiq)=str1(1:lnblnk(str1))//txtp(iiiq)
              enddo
           endif
        end do
       if(ii.ne.nqmx) then
       print*,'WARNING'
       print*,'le nombre de traceurs et de moments eventuels'
       print*,'est inferieur a nqmx '
       endif
       if (iiq.gt.nqmx) then
       print*,'le choix des schemas est incompatible avec '
       print*,'la dimension nqmx (nombre de traceurs)'
       print*,'verifier traceur.def ou la namelist INCA'
       print*,'ou recompiler avec plus de traceurs'
       stop
       endif
      iiq=0
      do iq=1,nqmx
         if(iadv(iq).ge.0) then
             iiq=iiq+1
             niadv(iiq)=iq
         endif
      end do
      return
999   format (i2,1x,i2,1x,a8)
      END
