!           PROGRAM les2lmdz
      module les2lmdz
      implicit none

      public :: readlesfiles
      save

        integer :: kmax
        logical :: llesread = .true.
        real :: z0,ps,thls,xlat,xlon,xday,xtime,wtsurf,wqsurf,frac
        real,allocatable,dimension(:) :: height,
     .    thlprof,qtprof,uprof,vprof,ugprof,vgprof,
     .    wfls,dqtdxls,dqtdyls,dqtdtls,thlpcar

      contains
        subroutine readlesfiles

        integer, parameter :: ilesfile=1
        integer :: ierr,isurf,irad,imax,jtot,k
        logical :: lmoist,lcoriol,ltimedep
        real :: xsize,ysize
        real :: ustin,wsvsurf,timerad
        real,allocatable,dimension(:) :: e12prof
        character(80) :: chmess

        namelist/DOMAIN/ 
     .    imax,jtot,kmax,xsize,ysize,xlat,xlon,xday,xtime
        namelist/PHYSICS/ 
     .    z0,ustin,wtsurf,wqsurf,wsvsurf,ps,thls,
     .    lmoist,isurf,irad,timerad,lcoriol,ltimedep

        if(.not.(llesread)) return
        
!=====================================================================
!  Lire namelist pour initialiser des constantes
!=====================================================================
        open(ilesfile,file="namoptions.001",status='old',iostat=ierr)
c        open(ilesfile,file="namoptions.moi",status='old',iostat=ierr)
        if (ierr /= 0) stop 'ERROR:Namoptions does not exist'
        read (ilesfile,DOMAIN)
        write(6 ,DOMAIN)
        read (ilesfile,PHYSICS)
        write(6 ,PHYSICS)
        close(ilesfile)

        allocate(height(kmax),thlprof(kmax),qtprof(kmax),uprof(kmax),
     .           vprof(kmax),e12prof(kmax),ugprof(kmax),vgprof(kmax),
     .           wfls(kmax),dqtdxls(kmax),dqtdyls(kmax),dqtdtls(kmax),
     .           thlpcar(kmax))


       open (ilesfile,file='prof.inp.001',status='old',iostat=ierr)
!        open (ilesfile,file='prof.inp.moi',status='old',iostat=ierr)
        if (ierr /= 0) stop 'ERROR:Prof.inp does not exist'
ccc nrlmd
ccc        read (ilesfile,'(a80)') chmess
ccc        write(*,       '(a80)') chmess
ccc        read (ilesfile,'(a80)') chmess
        do k=1,kmax
c          read (ilesfile,"(F12.4,1x,5(G12.7,1x))") height(k),thlprof(k),
c     .	                    qtprof (k),
c     .                      uprof (k),vprof  (k),e12prof(k)
          read (ilesfile,*) height(k),thlprof(k),qtprof (k),
     .                      uprof (k),vprof  (k),e12prof(k)
c          write(*       ,*) height(k),thlprof(k),qtprof (k),
c     .                      uprof (k),vprof  (k),e12prof(k)
        enddo      
        close(ilesfile)

        open(ilesfile,file='lscale.inp.001',status='old',iostat=ierr)
c        open (ilesfile,file='lscale.inp.moi',status='old',iostat=ierr)
        if (ierr /= 0) stop 'ERROR:Lscale.inp does not exist'
ccc nrlmd	
ccc        read (ilesfile,'(a80)') chmess
ccc        write(*,       '(a80)') chmess
ccc        read (ilesfile,'(a80)') chmess
        do k=1,kmax
          read (ilesfile,*) height(k),ugprof(k),vgprof(k),wfls(k),
     .                      dqtdxls(k),dqtdyls(k),dqtdtls(k),thlpcar(k)
!          write(*       ,*) height(k),ugprof(k),vgprof(k),wfls(k),
!     .                      dqtdxls(k),dqtdyls(k),dqtdtls(k),thlpcar(k)
        end do
        close(ilesfile)
        deallocate(e12prof)

        end subroutine readlesfiles


        subroutine endlesfiles       
        implicit none

        if(.not.(llesread)) return
        deallocate(height,thlprof,qtprof,uprof,vprof,thlpcar,
     .             ugprof,vgprof,wfls,dqtdxls,dqtdyls,dqtdtls)

        end subroutine endlesfiles

      end module les2lmdz



ccc nrlmd
ccc      PROGRAM fire
      PROGRAM nico

      use phys_state_var_mod
      use comgeomphy
      use dimphy
      use surface_data, only : type_ocean,ok_veget
      use pbl_surface_mod, only : pbl_surface_init
      use fonte_neige_mod, only : fonte_neige_init

      use les2lmdz!, only : readlesfiles

      implicit none
#include "dimensions.h"
#include "YOMCST.h"
#include "control.h"
#include "clesphys.h"
#include "dimsoil.h"
#include "indicesol.h"
!#include "dimphy.h"


!---------------------------------------------------------------------
!  Arguments d' initialisations de la physique (USER DEFINE)
!---------------------------------------------------------------------
      integer, parameter :: ngrid=1
      real :: day_ini  = 15.
ccc nrlmd      real :: timestep = 30.  ! pas de temps de la physique (s)
      real :: timestep = 1800.
      real :: airefi   = 1.
      real :: zcufi    = 1.
      real :: zcvfi    = 1.

      integer :: demih_pas
      logical :: ok_flux_surf
      real :: fsens
      real :: flat
      real :: tsol     = 293.0
      real :: rugos    = 0.15
      real :: qsol(1:2)= (/11.1,0.0/)
      real :: psol     = 101250.0
      real :: albedo   = 0.19

      real :: time     = 0.
ccc nrlmd      real :: fnday    = 1.    ! nombre de jours
      real :: fnday = 120.
      real :: day      = 217.
      real :: paire    = 1.     ! aire de la maille
      real :: day1
      common /flux_arp/fsens,flat,ok_flux_surf

!---------------------------------------------------------------------
!  Declarations concernant la discretisation verticale:
!---------------------------------------------------------------------
      real :: pa   = 5e4
      real :: preff= 1.01325e5
      real :: ap(llm+1),bp(llm+1),dpres(llm)
      real :: presnivs(llm),nivsigs(llm),nivsig(llm+1)
      real :: play (llm),zlay (llm),sig_s(llm),plev(llm+1)
      real :: playd(llm),zlayd(llm)


!---------------------------------------------------------------------
!  Declarations concernant les variables
!---------------------------------------------------------------------
      integer :: iq
      real :: phi(llm)
      real :: teta(llm),temp(llm),u(llm),v(llm),q(llm,nqmx)
      real :: omega(llm+1),omega2(llm+1),rho(llm+1)
      real :: ug(llm),vg(llm),fcoriolis
      real :: du(llm),dv(llm),dt(llm),dq(llm,nqmx)
      real :: du_dyn(llm),dv_dyn(llm),dt_dyn(llm),dq_dyn(llm,nqmx)
      real :: dt_cooling(llm),d_t_cool(llm),d_th_adv(llm)
      real :: dq_cooling(llm),d_q_cool(llm),d_q_adv(llm,nqmx)
      real :: ht(100),hq(100),hw(100)
      real :: tmpvar(llm)

!---------------------------------------------------------------------
!  Ajouts initialisation des surfaces
!---------------------------------------------------------------------
      real :: run_off_lic_0(1) = 0.
      real :: fder(1),snsrf(1,nbsrf),qsolsrf(1,nbsrf)
      real :: evap(1,nbsrf),frugs(1,nbsrf)
      real :: tsoil(1,nsoilmx,nbsrf)
      real :: agesno(1,nbsrf)=50.0
!      real :: tslab(1), seaice(1)

!---------------------------------------------------------------------
!  Declaration pour l'appel a phyredem
!---------------------------------------------------------------------
      logical :: ok_writedem =.true.
      real :: rugsrel = 0.0 ! (rugsrel = rugoro)
 
      
!---------------------------------------------------------------------
!  Declaration pour l'appel a physiq
!---------------------------------------------------------------------
      integer, parameter :: longcles=20
      logical :: firstcall=.true.
      logical :: lastcall=.false.
      real :: phis    = 0.0
      real :: clesphy0(longcles) = 0.0
      real :: dpsrf 

!      real :: sn      = 0.0
!      real :: deltat  = 0.0    ! ne sert que pour les slab_ocean

!---------------------------------------------------------------------
!  Arguments d' initialisations des conditions aux limites
!---------------------------------------------------------------------
      integer, parameter :: yd = 360
      real :: phy_nat (yd) = 0.0 ! 0=ocean libre,1=land,2=glacier,3=banquise
      real :: phy_alb (yd)  ! Albedo land only (old value condsurf_jyg=0.3)
      real :: phy_sst (yd)  ! SST
      real :: phy_bil (yd) = 1.0 ! Ne sert que pour les slab_ocean
      real :: phy_rug (yd) ! Longueur rugosite utilisee sur land only
      real :: phy_ice (yd) = 0.0 ! Fraction de glace
      real :: phy_fter(yd) = 0.0 ! Fraction de terre
      real :: phy_foce(yd) = 0.0 ! Fraction de ocean
      real :: phy_fsic(yd) = 0.0 ! Fraction de glace
      real :: phy_flic(yd) = 0.0 ! Fraction de glace

!---------------------------------------------------------------------
!  Fichiers et d'autres variables
!---------------------------------------------------------------------
      integer :: aslun,ierr,k,l,i,it=1,mxcalc
      character( 80) :: ans,file_forctl, file_fordat, file_start
      character(100) :: file1,var
      character(  2) :: cnbl

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! INITIALISATIONS
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
       open(4141,file='temp002')
      print*,'avant init_phys_lmdz'
!=====================================================================
! Initialisation des dimensions et de la geometrie
!=====================================================================

      call init_phys_lmdz(1,1,llm,nqmx-2,1,1)
      print*,'apres init_phys_lmdz'
      call suphel
      call initcomgeomphy
      call iniadvtrac(nqmx)
      call phys_state_var_init

      if (ngrid.ne.klon) then
         print*,'stop in inifis'
         print*,'Probleme de dimensions :'
         print*,'ngrid = ',ngrid
         print*,'klon  = ',klon
         stop
      endif

!=====================================================================
!  Profils initiaux
!=====================================================================

      call readlesfiles
      rlat = 33.25 ! FIRE Lat=  33 15'N
      rlon =-119.50 ! FIRE Lon= 119 30'W
      psol=ps
      rugos=z0
      tsol=thls
      rlat=xlat
      rlon=xlon
      day =xday
      day1= day
      time=xtime
      rho(1)=psol/(rd*tsol*(1.+(rv/rd-1.)*qsol(1)/1e3)) 
      ok_flux_surf=.false.
      fsens=-wtsurf*rcpd*rho(1)
      flat=-wqsurf*rlvtt*rho(1)

      print*,'FLUX ',wtsurf,wqsurf,rcpd,rho(1),rlvtt,fsens,flat

!---------------------------------------------------------------------
! Initialisation de la discretisation verticale et
! calcul des pressions de milieu et inter couches
!---------------------------------------------------------------------

      call disvert(pa,preff,ap,bp,dpres,presnivs,nivsigs,nivsig)
      sig_s=presnivs/preff
      plev =ap+bp*psol
      play = 0.5*(plev(1:llm)+plev(2:llm+1))
      zlay=-rd*300.*log(play/psol)/rg

      zmea=0.
      zstd=0.
      zsig=0.
      zgam=0.
      radsol=0.
      open(252,file='result_me')   !Ouvre fichier pour moi
      write(252,*)  wtsurf,wqsurf,rcpd,rho(1),rlvtt,fsens,flat
      write(252,*)  'pause'

!----------------------------------------------------------------------
! Interpolation of the profiles given on the input file to
! model levels
!----------------------------------------------------------------------
      do l=1,llm
        ! Above the max altutide of the input file

        if (zlay(l)<height(kmax)) mxcalc=l

        frac = (height(kmax)-zlay(l))/(height (kmax)-height(kmax-1))
        teta(l) =thlprof(kmax)-frac*(thlprof(kmax)-thlprof(kmax-1))
        q(l,1)  = qtprof(kmax)-frac*( qtprof(kmax)- qtprof(kmax-1))
        u(l)    =  uprof(kmax)-frac*(  uprof(kmax)-  uprof(kmax-1))
        v(l)    =  vprof(kmax)-frac*(  vprof(kmax)-  vprof(kmax-1))
        ug(l)   = ugprof(kmax)-frac*( ugprof(kmax)- ugprof(kmax-1))
        vg(l)   = vgprof(kmax)-frac*( vgprof(kmax)- vgprof(kmax-1))
        omega(l)=   wfls(kmax)-frac*(   wfls(kmax)-   wfls(kmax-1))

        dq_dyn(l,1) = dqtdtls(kmax)-frac*(dqtdtls(kmax)-dqtdtls(kmax-1))
        dt_cooling(l)
     .          =thlpcar(kmax)-frac*(thlpcar(kmax)-thlpcar(kmax-1))
        do k=2,kmax
          frac = (height(k)-zlay(l))/(height(k)-height(k-1))
          if(l==1) print*,k,height(k),thlprof(k)
          if(zlay(l)>height(k-1).and.zlay(l)<height(k)) then
            teta(l) =thlprof(k)-frac*(thlprof(k)-thlprof(k-1))
            q(l,1)  = qtprof(k)-frac*( qtprof(k)- qtprof(k-1))
            u(l)    =  uprof(k)-frac*(  uprof(k)-  uprof(k-1))
            v(l)    =  vprof(k)-frac*(  vprof(k)-  vprof(k-1))
            ug(l)   = ugprof(k)-frac*( ugprof(k)- ugprof(k-1))
            vg(l)   = vgprof(k)-frac*( vgprof(k)- vgprof(k-1))
            omega(l)=   wfls(k)-frac*(   wfls(k)-   wfls(k-1))
            dq_dyn(l,1)=dqtdtls(k)-frac*(dqtdtls(k)-dqtdtls(k-1))
            dt_cooling(l)
     .              =thlpcar(k)-frac*(thlpcar(k)-thlpcar(k-1))
          elseif(zlay(l)<height(1)) then
            teta(l) =thlprof(1)
            q(l,1)  = qtprof(1)
            u(l)    =  uprof(1)
            v(l)    =  vprof(1)
            ug(l)   = ugprof(1)
            vg(l)   = vgprof(1)
            omega(l)=   wfls(1)
            dq_dyn(l,1)  =dqtdtls(1)
            dt_cooling(l)=thlpcar(1)
          endif
        enddo 

        temp(l) = teta(l)*(play(l)/psol)**rkappa
         temp(l)=max(min(temp(l),330.),200.)
         teta(l)=temp(l)/(play(l)/psol)**rkappa

        rho(l)  = play(l)/(rd*temp(l)*(1.+(rv/rd-1.)*q(l,1)))
        omega2(l)=-rho(l)*omega(l)
        omega(l)= omega(l)*(-rg*rho(l)) !en Pa/s
        if (l>1) then
        if(zlay(l-1)>height(kmax)) then
           omega(l)=0.0
           omega2(l)=0.0
        endif   
        endif
        if(q(l,1)<0.) q(l,1)=0.0
        q(l,2)  = 0.0
ccc=nrlmd
ccc        d_th_adv(l)=-7.5e-8*max(zlay(l),500.)
ccc	   d_q_adv(l,1)=3.e-11*max(zlay(l),500.)
        !if(zlay(l-1)>height(kmax)) cycle
        write(12,'(I3,F9.2,F7.1,10e12.4)'),l,zlay(l),play(l)/1e2,
     .        rho(l),temp(l),teta(l),ug(l),vg(l),omega(l),dq_dyn(l,1),
     .        dt_cooling(l),d_th_adv(l),d_q_adv(l,1)
         write(252,'(I3,F9.2,F7.1,11e12.4)'),l,zlay(l),play(l)/1e2,
     .          rho(l),temp(l),teta(l),ug(l),vg(l),omega(l),dq_dyn(l,1),
     .          dt_cooling(l),d_th_adv(l),d_q_adv(l,1),omega2(l)
      enddo

      print*,'mxcalc=',mxcalc
      print*,'zlay=',zlay(mxcalc)
      print*,'play=',play(mxcalc)

!=====================================================================
! Initialisations de la physique
!=====================================================================

      day_step =nint(rday/timestep)
      timestep =rday/day_step
      demih_pas=nint(1800./timestep)

      call iniphysiq(ngrid,llm,rday,day_ini,timestep,
     .     rlat,rlon,airefi,zcufi,zcvfi,ra,rg,rd,rcpd)
      print*,'apres iniphysiq'

      co2_ppm= 330.0
      solaire=1370.0

!
! Ecriture etat initial physique
!
!     timestep   = dtvr * float(iphysiq)

      nbapp_rad=48
      iflag_con=0
      radpas      = nint(rday/timestep/float(nbapp_rad))
      clesphy0(1) = float(iflag_con)
      clesphy0(2) = float(nbapp_rad)
!     if(cycle_diurne) clesphy0(3) =  1. 
      clesphy0(3)=1. ! cycle_diurne
      clesphy0(4)=1. ! soil_model
      clesphy0(5)=1. ! new_oliq
      clesphy0(6)=0. ! ok_orodr
      clesphy0(7)=0. ! ok_orolf
      clesphy0(8)=0. ! ok_limitvrai

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
! Ecriture du startphy avant le premier appel a la physique.
! On le met juste avant pour avoir acces a tous les champs
! Initialisations necessaires avant phyredem
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      if (ok_writedem) then
        type_ocean = "force"
        call fonte_neige_init(run_off_lic_0)

        !Variables supplementaires pour appel a plb_surface_init
        fder=0.
        snsrf(1,:)=0.        ! couverture de neige des sous surface
        qsolsrf(1,:)=qsol(1) ! humidite du sol des sous surface
        evap=0.
        frugs(1,:)=rugos     ! couverture de neige des sous surface
!        agesno  = 50.0
        tsoil(:,:,:)=tsol
        call pbl_surface_init(qsol, fder, snsrf, qsolsrf,
     .       evap, frugs, agesno, tsoil)

        !Ocean force

        print*,'avant phyredem'
        pctsrf(1,:)=0.
        pctsrf(1,is_oce)=1.
        zmasq=pctsrf(1,is_ter)+pctsrf(1,is_lic)
        ftsol=tsol
        rain_fall=0.
        snow_fall=0.
        solsw=0.
        sollw=0.
        radsol=0.
        t_ancien(1,:)=temp(:)
        q_ancien(1,:)=q(:,1)
        rnebcon=0.
        ratqs=0.
        clwcon=0.
        pbl_tke=1.e-8

!       ftsoil(:,:,:)=tsol
!        tslab(:)=tsol
!        seaice(:)=0.

        ema_work1=0.
        ema_work2=0.

        call phyredem ("startphy.nc")


        ok_writedem=.false.
        print*,'apres phyredem'

      endif
      
!=====================================================================
! Creation des conditions aux limites:
!=====================================================================

      do i=1,yd
        phy_alb(i)  = albedo
        phy_sst(i)  = tsol
        phy_rug(i)  = rugos
        phy_fter(i) = pctsrf(1,is_ter)
        phy_foce(i) = pctsrf(1,is_oce)
        phy_fsic(i) = pctsrf(1,is_sic)
        phy_flic(i) = pctsrf(1,is_lic)
      enddo

      call writelim (phy_nat,phy_alb,phy_sst,phy_bil,phy_rug,
     .               phy_ice,phy_fter,phy_foce,phy_flic,phy_fsic)

      call phys_state_var_end
!=====================================================================
! DEBUT DE L'INTEGRATION TEMPORELLE:
!=====================================================================
 
      fcoriolis=2.*sin(rpi*rlat(1)/180.)*romega

      open(1,file='field.001')   !Ouvre fichier d'ecriture
 
      write(252,*) 'rg',rg
      write(252,*) 'llm ', llm
      write(252,*) 'rho1 ', rho(1),rho(2)
      write(1,'(a)') '# Initial state'
!     do l = 1, llm depassement de tableau
      do l = 2, llm
        if(zlay(l-1)>height(kmax)) cycle
        write(1,'(I3,F8.2,F7.1,3F9.4,F8.4,E12.4,3F9.4)') l,
     .    zlay(l),
     .    play(l)/1e2,
     .    temp(l),
     .    teta(l),
     .    teta(l)*(1.+(rv/rd-1.)*q(l,1)),
     .    q(l,1)*1e3,
     .    q(l,2)*1e3,
     .    u(l),
     .    v(l),
     .    omega(l)
         write(252,*) rho(l)
      enddo

      do while(it.le.nint(fnday*day_step))

        print*,'XXXXXXXXXXXXXXXXXXX ITAP=',it,nint(fnday*day_step)
        print*,'PAS DE TEMPS ',timestep

!---------------------------------------------------------------------
!   Calcul du geopotentiel 
!---------------------------------------------------------------------
        phi(1)=RD*temp(1)*(plev(1)-play(1))/(.5*(plev(1)+play(1)))
        do l = 1, llm-1
          phi(l+1)=phi(l)+RD*(temp(l)+temp(l+1))*
     .    (play(l)-play(l+1))/(play(l)+play(l+1))
        enddo
       write(4141,*) ngrid,llm,nqmx,firstcall,lastcall,day,time,timestep
         write(4141,*) 'plev ',plev
         write(4141,*) 'play ',play
         write(4141,*) 'phi ',phi
         write(4141,*) 'presnivs',presnivs
         write(4141,*) 'clesphy0 ',clesphy0
        print*,'APRES PHYS1'
         if (day .NE. day1) then
             day = day1
         endif
!---------------------------------------------------------------------
!   Appel de la physique
!---------------------------------------------------------------------
        call physiq(ngrid,llm,nqmx,
     .              firstcall,lastcall,
     .              day,time,timestep,
     .              plev,play,phi,phis,presnivs,clesphy0,
     .              u,v,temp,q,omega2,
     .              du,dv,dt,dq,dpsrf)

        firstcall=.false.
        print*,'APRES PHYS'

!---------------------------------------------------------------------
!   Ajout des tendances de la physique
!---------------------------------------------------------------------
ccc nrlmd
        u(1:mxcalc)=u(1:mxcalc)
ccc     $	+ timestep*du(1:mxcalc)
        v(1:mxcalc)=v(1:mxcalc)
ccc     $	+ timestep*dv(1:mxcalc)
        q(1:mxcalc,:)=q(1:mxcalc,:)+timestep*dq(1:mxcalc,:)
ccc 
        q(1:mxcalc,:)=q(1:mxcalc,:)
ccc	+timestep*d_q_adv(1:mxcalc,:)
        temp(1:mxcalc)=temp(1:mxcalc)+timestep*dt(1:mxcalc)
ccc
ccc        temp(1:mxcalc)=temp(1:mxcalc)
ccc     s   +timestep*((play/psol)**rkappa)*d_th_adv(1:mxcalc)
        teta=temp*(psol/play)**rkappa
          
!---------------------------------------------------------------------
!   Ajout des tendances de grand-echelle
!---------------------------------------------------------------------
ccc nrlmd on bloque les tendances de grande chelle
        u(1:mxcalc)=u(1:mxcalc)
ccc     s  +fcoriolis*(v(1:mxcalc)-vg(1:mxcalc))*timestep  ! Comp. agestrophic du vent u
        v(1:mxcalc)=v(1:mxcalc)
ccc     s  -fcoriolis*(u(1:mxcalc)-ug(1:mxcalc))*timestep  ! Comp. agestrophic du vent v
        q(1:mxcalc,:)=q(1:mxcalc,:)
ccc	+ timestep*dq_dyn(1:mxcalc,:)            !
        teta=teta+timestep*dt_cooling  ! Taux de chauffage ou refroid.

!---------------------------------------------------------------------
! Advection eventuelle avec des vitesses pour l'eau et la temperature.
!---------------------------------------------------------------------
!        write(6,'(a17,5f12.6)') 'teta avant vert2 ',(teta(l),l=1,5)
!        write(6,'(a18,5e12.6)') 'omega avant vert2 ',(omega(l),l=1,5)
ccc nrlmd
ccc        tmpvar=teta
ccc        call advect_vert(llm,omega,timestep,tmpvar,plev)
ccc
ccc        teta(1:mxcalc)=tmpvar(1:mxcalc)
ccc        tmpvar(:)=q(:,1)
ccc        call advect_vert(llm,omega,timestep,tmpvar,plev)
ccc        q(1:mxcalc,1)=tmpvar(1:mxcalc)
ccc        tmpvar(:)=q(:,2)
ccc        call advect_vert(llm,omega,timestep,tmpvar,plev)
ccc        q(1:mxcalc,2)=tmpvar(1:mxcalc)

!        write(6,'(a17,5f12.6)') 'teta apres vert2 ',(teta(l),l=1,5)

!---------------------------------------------------------------------
!   Calcul de la temperature d'air 
!---------------------------------------------------------------------        
        temp=teta*(play/psol)**rkappa

        write(1,'(//a,i5)') '#',it
!       do l = 1, llm  depassement de tableau
        do l = 2, llm
          if(zlay(l-1)>height(kmax)) cycle
          write(1,'(I3,F8.2,F7.1,3F9.4,F8.4,E12.4,3F9.4)') l,
     .      zlay(l),
     .      play(l)/1e2,
     .      temp(l),
     .      teta(l),
     .      teta(l)*(1.+(rv/rd-1.)*q(l,1)),
     .      q(l,1)*1e3,
     .      q(l,2)*1e3,
     .      u(l),
     .      v(l),
     .      omega(l) 
        enddo

        day =day+1./day_step
        time=day-int(day)
        it=it+1

      enddo
      close(1)
      print*,'Pas de temps final ',it-1
      stop 'Game over!'

      end
#include "1DUTILS.h"
      function ismin(n,sx,incx)

      implicit none
      integer n,i,incx,ismin,ix
      real sx((n-1)*incx+1),sxmin

      ix=1
      ismin=1
      sxmin=sx(1)
      do i=1,n-1
         ix=ix+incx
         if(sx(ix).lt.sxmin) then
             sxmin=sx(ix)
             ismin=i+1
         endif
      enddo

      return
      end

      function ismax(n,sx,incx)

      implicit none
      integer n,i,incx,ismax,ix
      real sx((n-1)*incx+1),sxmax

      ix=1
      ismax=1
      sxmax=sx(1)
      do i=1,n-1
         ix=ix+incx
         if(sx(ix).gt.sxmax) then
             sxmax=sx(ix)
             ismax=i+1
         endif
      enddo

      return
      end

